[svn.haxx.se] · SVN Dev · SVN Users · SVN Org · TSVN Dev · TSVN Users · Subclipse Dev · Subclipse Users · this month's index

Re: possible bug: 'working copy path does not exist' during merge

From: Stefan Sperling <stsp_at_elego.de>
Date: Fri, 22 Aug 2008 19:28:54 +0200

On Fri, Aug 22, 2008 at 09:16:41AM -0400, Paul Burba wrote:
> On Fri, Aug 22, 2008 at 8:17 AM, Stefan Sperling <stsp_at_elego.de> wrote:
> > On Fri, Aug 22, 2008 at 02:10:16PM +0200, Stefan Sperling wrote:
> >> The attached script reproduces a merge that cannot be run
> >> because it fails with:
> >> "svn: Working copy path 'alpha.copied' does not exist in repository"
> >
> > The script has a small comment typo:
> >
> > # In the branch, move a file different to the copy target path
> >
> > Should of course be:
> >
> > # In the branch, move a different file to the copy target path
> >
> > Just to prevent potential confusion,
> > Stefan
>
> Stefan,
>
> This looks like another instance of issue #3067. I'm currently
> looking into another similar problem that Hyrum encountered and will
> look into this also. More soon...

FYI, the same thing happens when the file is moved in trunk.
So the script patched as follows also reproduces the problem:

--- svn-merge-wc-path-does-not-exist-in-repo-issue.sh 2008-08-22 13:54:26.000000000 +0200
+++ svn-merge-wc-path-does-not-exist-in-repo-issue2.sh 2008-08-22 19:22:55.000000000 +0200
@@ -26,12 +26,12 @@
 svn checkout $trunk_url $trunk
 svn checkout $branch_url $branch
 
-# Copy a file in trunk
-svn copy $trunk/alpha $trunk/alpha.copied
-svn commit -m "copied alpha" $trunk
+# Move a file in trunk
+svn move $trunk/alpha $trunk/alpha.moved
+svn commit -m "moved alpha" $trunk
 
 # In the branch, move a file different to the copy target path.
-svn mv $branch/beta $branch/alpha.copied
+svn mv $branch/beta $branch/alpha.moved
 # Committing here does not affect the result!
 
 # Merge the copy into the branch

Which, of course, isn't surprising given the way we implement moves.

I still wanted to point this out because knowing all the different
ways our users can run into this problem helps us recognising
problem reports as such.

Stefan

---------------------------------------------------------------------
To unsubscribe, e-mail: dev-unsubscribe_at_subversion.tigris.org
For additional commands, e-mail: dev-help_at_subversion.tigris.org
Received on 2008-08-22 19:29:15 CEST

This is an archived mail posted to the Subversion Dev mailing list.

This site is subject to the Apache Privacy Policy and the Apache Public Forum Archive Policy.